@@ -1,13 +1,19 @@
 from django.db import models
 from django.utils.translation import ugettext as _
+
+from plugshop import settings
 from plugshop.utils import is_default_model, get_categories
+from mptt.fields import TreeForeignKey
 
 class ProductAbstract(models.Model):
     class Meta:
         abstract = True
         verbose_name  = _('product')
         verbose_name_plural = _('products')
-
+        
+    category = TreeForeignKey(settings.CATEGORY_MODEL, blank=True, null=True,
+                                verbose_name=_('category'),
+                                related_name='products')
     name = models.CharField(_('name'), blank=False, max_length=200)
     slug = models.SlugField(_('slug'), blank=False, unique=True)
     price = models.PositiveIntegerField(_('price'), blank=False)
